#[repr(C)]pub struct WlanPhyGetCountryResponse {
pub country: [u8; 2],
}Fields
country: [u8; 2]Trait Implementations
Sourceimpl Clone for WlanPhyGetCountryResponse
impl Clone for WlanPhyGetCountryResponse
Sourcefn clone(&self) -> WlanPhyGetCountryResponse
fn clone(&self) -> WlanPhyGetCountryResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for WlanPhyGetCountryResponse
Sourceimpl Debug for WlanPhyGetCountryResponse
impl Debug for WlanPhyGetCountryResponse
Sourceimpl<D: ResourceDialect> Decode<WlanPhyGetCountryResponse, D> for WlanPhyGetCountryResponse
impl<D: ResourceDialect> Decode<WlanPhyGetCountryResponse, D> for WlanPhyGetCountryResponse
Sourceimpl<D: ResourceDialect> Encode<WlanPhyGetCountryResponse, D> for &WlanPhyGetCountryResponse
impl<D: ResourceDialect> Encode<WlanPhyGetCountryResponse, D> for &WlanPhyGetCountryResponse
Sourceimpl<D: ResourceDialect, T0: Encode<Array<u8, 2>, D>> Encode<WlanPhyGetCountryResponse, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<Array<u8, 2>, D>> Encode<WlanPhyGetCountryResponse, D> for (T0,)
impl Eq for WlanPhyGetCountryResponse
Sourceimpl Hash for WlanPhyGetCountryResponse
impl Hash for WlanPhyGetCountryResponse
Sourceimpl Ord for WlanPhyGetCountryResponse
impl Ord for WlanPhyGetCountryResponse
Sourcefn cmp(&self, other: &WlanPhyGetCountryResponse) -> Ordering
fn cmp(&self, other: &WlanPhyGetCountryResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for WlanPhyGetCountryResponse
impl PartialEq for WlanPhyGetCountryResponse
Sourcefn eq(&self, other: &WlanPhyGetCountryResponse) -> bool
fn eq(&self, other: &WlanPhyGetCountryResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for WlanPhyGetCountryResponse
impl PartialOrd for WlanPhyGetCountryResponse
impl Persistable for WlanPhyGetCountryResponse
impl StructuralPartialEq for WlanPhyGetCountryResponse
Sourceimpl TypeMarker for WlanPhyGetCountryResponse
impl TypeMarker for WlanPhyGetCountryResponse
Sourcetype Owned = WlanPhyGetCountryResponse
type Owned = WlanPhyGetCountryResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for WlanPhyGetCountryResponse
impl ValueTypeMarker for WlanPhyGetCountryResponse
Sourcetype Borrowed<'a> = &'a WlanPhyGetCountryResponse
type Borrowed<'a> = &'a WlanPhyGetCountryResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for WlanPhyGetCountryResponse
impl RefUnwindSafe for WlanPhyGetCountryResponse
impl Send for WlanPhyGetCountryResponse
impl Sync for WlanPhyGetCountryResponse
impl Unpin for WlanPhyGetCountryResponse
impl UnsafeUnpin for WlanPhyGetCountryResponse
impl UnwindSafe for WlanPhyGetCountryResponse