pub struct WlanPhyGetPowerStateResponse {
pub power_on: Option<bool>,
/* private fields */
}Fields
power_on: Option<bool>Trait Implementations
Sourceimpl Clone for WlanPhyGetPowerStateResponse
impl Clone for WlanPhyGetPowerStateResponse
Sourcefn clone(&self) -> WlanPhyGetPowerStateResponse
fn clone(&self) -> WlanPhyGetPowerStateResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WlanPhyGetPowerStateResponse
impl Debug for WlanPhyGetPowerStateResponse
Sourceimpl<D: ResourceDialect> Decode<WlanPhyGetPowerStateResponse, D> for WlanPhyGetPowerStateResponse
impl<D: ResourceDialect> Decode<WlanPhyGetPowerStateResponse, D> for WlanPhyGetPowerStateResponse
Sourceimpl Default for WlanPhyGetPowerStateResponse
impl Default for WlanPhyGetPowerStateResponse
Sourcefn default() -> WlanPhyGetPowerStateResponse
fn default() -> WlanPhyGetPowerStateResponse
Returns the “default value” for a type. Read more
Sourceimpl<D: ResourceDialect> Encode<WlanPhyGetPowerStateResponse, D> for &WlanPhyGetPowerStateResponse
impl<D: ResourceDialect> Encode<WlanPhyGetPowerStateResponse, D> for &WlanPhyGetPowerStateResponse
Sourceimpl PartialEq for WlanPhyGetPowerStateResponse
impl PartialEq for WlanPhyGetPowerStateResponse
Sourcefn eq(&self, other: &WlanPhyGetPowerStateResponse) -> bool
fn eq(&self, other: &WlanPhyGetPowerStateResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Persistable for WlanPhyGetPowerStateResponse
impl StructuralPartialEq for WlanPhyGetPowerStateResponse
Sourceimpl TypeMarker for WlanPhyGetPowerStateResponse
impl TypeMarker for WlanPhyGetPowerStateResponse
Sourcetype Owned = WlanPhyGetPowerStateResponse
type Owned = WlanPhyGetPowerStateResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for WlanPhyGetPowerStateResponse
impl ValueTypeMarker for WlanPhyGetPowerStateResponse
Sourcetype Borrowed<'a> = &'a WlanPhyGetPowerStateResponse
type Borrowed<'a> = &'a WlanPhyGetPowerStateResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for WlanPhyGetPowerStateResponse
impl RefUnwindSafe for WlanPhyGetPowerStateResponse
impl Send for WlanPhyGetPowerStateResponse
impl Sync for WlanPhyGetPowerStateResponse
impl Unpin for WlanPhyGetPowerStateResponse
impl UnsafeUnpin for WlanPhyGetPowerStateResponse
impl UnwindSafe for WlanPhyGetPowerStateResponse