pub struct WlanPhyGetSupportedMacRolesResponse {
pub supported_mac_roles: Option<Vec<WlanMacRole>>,
/* private fields */
}Fields
supported_mac_roles: Option<Vec<WlanMacRole>>Trait Implementations
Sourceimpl Clone for WlanPhyGetSupportedMacRolesResponse
impl Clone for WlanPhyGetSupportedMacRolesResponse
Sourcefn clone(&self) -> WlanPhyGetSupportedMacRolesResponse
fn clone(&self) -> WlanPhyGetSupportedMacRolesResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D: ResourceDialect> Decode<WlanPhyGetSupportedMacRolesResponse, D> for WlanPhyGetSupportedMacRolesResponse
impl<D: ResourceDialect> Decode<WlanPhyGetSupportedMacRolesResponse, D> for WlanPhyGetSupportedMacRolesResponse
Sourceimpl Default for WlanPhyGetSupportedMacRolesResponse
impl Default for WlanPhyGetSupportedMacRolesResponse
Sourcefn default() -> WlanPhyGetSupportedMacRolesResponse
fn default() -> WlanPhyGetSupportedMacRolesResponse
Returns the “default value” for a type. Read more
Sourceimpl<D: ResourceDialect> Encode<WlanPhyGetSupportedMacRolesResponse, D> for &WlanPhyGetSupportedMacRolesResponse
impl<D: ResourceDialect> Encode<WlanPhyGetSupportedMacRolesResponse, D> for &WlanPhyGetSupportedMacRolesResponse
Sourceimpl PartialEq for WlanPhyGetSupportedMacRolesResponse
impl PartialEq for WlanPhyGetSupportedMacRolesResponse
Sourcefn eq(&self, other: &WlanPhyGetSupportedMacRolesResponse) -> bool
fn eq(&self, other: &WlanPhyGetSupportedMacRolesResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Persistable for WlanPhyGetSupportedMacRolesResponse
impl StructuralPartialEq for WlanPhyGetSupportedMacRolesResponse
Sourceimpl TypeMarker for WlanPhyGetSupportedMacRolesResponse
impl TypeMarker for WlanPhyGetSupportedMacRolesResponse
Sourcetype Owned = WlanPhyGetSupportedMacRolesResponse
type Owned = WlanPhyGetSupportedMacRolesResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for WlanPhyGetSupportedMacRolesResponse
impl ValueTypeMarker for WlanPhyGetSupportedMacRolesResponse
Sourcetype Borrowed<'a> = &'a WlanPhyGetSupportedMacRolesResponse
type Borrowed<'a> = &'a WlanPhyGetSupportedMacRolesResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for WlanPhyGetSupportedMacRolesResponse
impl RefUnwindSafe for WlanPhyGetSupportedMacRolesResponse
impl Send for WlanPhyGetSupportedMacRolesResponse
impl Sync for WlanPhyGetSupportedMacRolesResponse
impl Unpin for WlanPhyGetSupportedMacRolesResponse
impl UnsafeUnpin for WlanPhyGetSupportedMacRolesResponse
impl UnwindSafe for WlanPhyGetSupportedMacRolesResponse