pub struct WlanPhyGetTxPowerScenarioResponse {
pub scenario: TxPowerScenario,
}Fields
scenario: TxPowerScenarioTrait Implementations
Sourceimpl Clone for WlanPhyGetTxPowerScenarioResponse
impl Clone for WlanPhyGetTxPowerScenarioResponse
Sourcefn clone(&self) -> WlanPhyGetTxPowerScenarioResponse
fn clone(&self) -> WlanPhyGetTxPowerScenarioResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for WlanPhyGetTxPowerScenarioResponse
Sourceimpl<D: ResourceDialect> Decode<WlanPhyGetTxPowerScenarioResponse, D> for WlanPhyGetTxPowerScenarioResponse
impl<D: ResourceDialect> Decode<WlanPhyGetTxPowerScenarioResponse, D> for WlanPhyGetTxPowerScenarioResponse
Sourceimpl<D: ResourceDialect> Encode<WlanPhyGetTxPowerScenarioResponse, D> for &WlanPhyGetTxPowerScenarioResponse
impl<D: ResourceDialect> Encode<WlanPhyGetTxPowerScenarioResponse, D> for &WlanPhyGetTxPowerScenarioResponse
Sourceimpl<D: ResourceDialect, T0: Encode<TxPowerScenario, D>> Encode<WlanPhyGetTxPowerScenarioResponse, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<TxPowerScenario, D>> Encode<WlanPhyGetTxPowerScenarioResponse, D> for (T0,)
impl Eq for WlanPhyGetTxPowerScenarioResponse
Sourceimpl Ord for WlanPhyGetTxPowerScenarioResponse
impl Ord for WlanPhyGetTxPowerScenarioResponse
Sourcefn cmp(&self, other: &WlanPhyGetTxPowerScenarioResponse) -> Ordering
fn cmp(&self, other: &WlanPhyGetTxPowerScenarioResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for WlanPhyGetTxPowerScenarioResponse
impl PartialEq for WlanPhyGetTxPowerScenarioResponse
Sourcefn eq(&self, other: &WlanPhyGetTxPowerScenarioResponse) -> bool
fn eq(&self, other: &WlanPhyGetTxPowerScenarioResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for WlanPhyGetTxPowerScenarioResponse
impl PartialOrd for WlanPhyGetTxPowerScenarioResponse
impl Persistable for WlanPhyGetTxPowerScenarioResponse
impl StructuralPartialEq for WlanPhyGetTxPowerScenarioResponse
Sourceimpl TypeMarker for WlanPhyGetTxPowerScenarioResponse
impl TypeMarker for WlanPhyGetTxPowerScenarioResponse
Sourcetype Owned = WlanPhyGetTxPowerScenarioResponse
type Owned = WlanPhyGetTxPowerScenarioResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for WlanPhyGetTxPowerScenarioResponse
impl ValueTypeMarker for WlanPhyGetTxPowerScenarioResponse
Sourcetype Borrowed<'a> = &'a WlanPhyGetTxPowerScenarioResponse
type Borrowed<'a> = &'a WlanPhyGetTxPowerScenarioResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for WlanPhyGetTxPowerScenarioResponse
impl RefUnwindSafe for WlanPhyGetTxPowerScenarioResponse
impl Send for WlanPhyGetTxPowerScenarioResponse
impl Sync for WlanPhyGetTxPowerScenarioResponse
impl Unpin for WlanPhyGetTxPowerScenarioResponse
impl UnsafeUnpin for WlanPhyGetTxPowerScenarioResponse
impl UnwindSafe for WlanPhyGetTxPowerScenarioResponse